
#include <lubishev/Exception.h>
#include <lubishev/Settings.h>

#include <QFileDialog>
#include <iostream>

namespace lubishev {

Settings::Settings(QWidget *parent, QSettings &set) : QDialog(parent),
                                                      mSet(set) {
    setupUi(this);
    connect(mBtnBox, SIGNAL(clicked(QAbstractButton *)),
            this, SLOT(onBtn(QAbstractButton *)));
    connect(mBtnDB, SIGNAL(clicked()), this, SLOT(onPath()));
    // Load settings.
    mEdDB->setText(mSet.value("db.dir").toString());
}

void Settings::apply() {
    // Save settings.
    mSet.setValue("db.dir", mEdDB->text());
}

void Settings::cancel() {
    close();
}

void Settings::ok() {
    apply();
    close();
}

void Settings::onBtn(QAbstractButton *btn) {
    switch (mBtnBox->buttonRole(btn)) {
        case QDialogButtonBox::AcceptRole:
            ok();
            break;
        case QDialogButtonBox::RejectRole:
            cancel();
            break;
        case QDialogButtonBox::ApplyRole:
            apply();
            break;
        default:
            LUBISHEV_EXCEPTION("Must not happen", "Invalid button role");
    }
}

void Settings::onPath() {
    QString dir =
        QFileDialog::getExistingDirectory(this, tr("Open directory"));
    mEdDB->setText(dir);
}

} // namespace lubishev

